Learn R Programming

vangogh (version 0.1.3)

viz_palette: Visualise a Van Gogh palette with optional colorblind simulation

Description

Visualise a Van Gogh palette with optional colorblind simulation

Usage

viz_palette(
  name,
  show_hex = TRUE,
  colorblind = FALSE,
  type = "discrete",
  n = NULL
)

Arguments

name

Palette name

show_hex

Display hex codes (TRUE/FALSE)

colorblind

Show colorblind simulation (TRUE/FALSE)

type

Either "discrete" or "continuous"

n

Number of colors for continuous palettes